[void] [System.Reflection.Assembly]::LoadWithPartialName("System.Windows.Forms")

$form = New-Object System.Windows.Forms.Form
$form.width = 500
$form.height = 400
$form.text = "Choose Qt graphics backend"
$form.topmost = $true

$Font = New-Object System.Drawing.Font("Times New Roman",12)
$form.Font = $Font

$qtogl = [System.Environment]::GetEnvironmentVariable('QT_OPENGL')
$qtangleplat = [System.Environment]::GetEnvironmentVariable('QT_ANGLE_PLATFORM')

function setEnvVars {
	param( $option )
	
	switch($option)
	{
		1 { [System.Environment]::SetEnvironmentVariable('QT_OPENGL', '', [System.EnvironmentVariableTarget]::User)
		    [System.Environment]::SetEnvironmentVariable('QT_ANGLE_PLATFORM', '', [System.EnvironmentVariableTarget]::User)
		}
		
		2 { [System.Environment]::SetEnvironmentVariable('QT_OPENGL', 'angle', [System.EnvironmentVariableTarget]::User)
		    [System.Environment]::SetEnvironmentVariable('QT_ANGLE_PLATFORM', 'd3d11', [System.EnvironmentVariableTarget]::User)
		}
		
		3 { [System.Environment]::SetEnvironmentVariable('QT_OPENGL', 'angle', [System.EnvironmentVariableTarget]::User)
		    [System.Environment]::SetEnvironmentVariable('QT_ANGLE_PLATFORM', 'd3d9', [System.EnvironmentVariableTarget]::User)
		}
		
		4 { [System.Environment]::SetEnvironmentVariable('QT_OPENGL', 'angle', [System.EnvironmentVariableTarget]::User)
		    [System.Environment]::SetEnvironmentVariable('QT_ANGLE_PLATFORM', 'warp', [System.EnvironmentVariableTarget]::User)
		}
		
		5 { [System.Environment]::SetEnvironmentVariable('QT_OPENGL', 'desktop', [System.EnvironmentVariableTarget]::User)
		}
		
		6 { [System.Environment]::SetEnvironmentVariable('QT_OPENGL', 'software', [System.EnvironmentVariableTarget]::User)
		}
	}
}

# Create a group that will contain your radio buttons
$MyGroupBox = New-Object System.Windows.Forms.GroupBox
$MyGroupBox.Location = '40,30'
$MyGroupBox.size = '400,230'
$MyGroupBox.text = $form.text

# Create the collection of radio buttons
$RadioButton1 = New-Object System.Windows.Forms.RadioButton
$RadioButton1.Location = '20,40'
$RadioButton1.size = '350,20'
$RadioButton1.Checked = (-not $qtogl) 
$RadioButton1.Text = "Default"

$RadioButton2 = New-Object System.Windows.Forms.RadioButton
$RadioButton2.Location = '20,70'
$RadioButton2.size = '350,20'
$RadioButton2.Checked = (($qtogl -eq "angle") -and ($qtangleplat -eq "d3d11"))
$RadioButton2.Text = "ANGLE - D3D11"

$RadioButton3 = New-Object System.Windows.Forms.RadioButton
$RadioButton3.Location = '20,100'
$RadioButton3.size = '350,20'
$RadioButton3.Checked = (($qtogl -eq "angle") -and ($qtangleplat -eq "d3d9"))
$RadioButton3.Text = "ANGLE - D3D9"

$RadioButton4 = New-Object System.Windows.Forms.RadioButton
$RadioButton4.Location = '20,130'
$RadioButton4.size = '350,20'
$RadioButton4.Checked = (($qtogl -eq "angle") -and ($qtangleplat -eq "warp"))
$RadioButton4.Text = "Warp"

$RadioButton5 = New-Object System.Windows.Forms.RadioButton
$RadioButton5.Location = '20,160'
$RadioButton5.size = '350,20'
$RadioButton5.Checked = ($qtogl -eq "desktop") 
$RadioButton5.Text = "OpenGL"

$RadioButton6 = New-Object System.Windows.Forms.RadioButton
$RadioButton6.Location = '20,190'
$RadioButton6.size = '350,20'
$RadioButton6.Checked = ($qtogl -eq "software")
$RadioButton6.Text = "Software"


# Add an OK button
$OKButton = new-object System.Windows.Forms.Button
$OKButton.Location = '130,300'
$OKButton.Size = '100,40' 
$OKButton.Text = 'OK'
$OKButton.DialogResult=[System.Windows.Forms.DialogResult]::OK

#Add a cancel button
$CancelButton = new-object System.Windows.Forms.Button
$CancelButton.Location = '255,300'
$CancelButton.Size = '100,40'
$CancelButton.Text = "Cancel"
$CancelButton.DialogResult=[System.Windows.Forms.DialogResult]::Cancel

# Add all the GroupBox controls on one line
$MyGroupBox.Controls.AddRange(@($Radiobutton1,$RadioButton2,$RadioButton3,$RadioButton4,$RadioButton5,$RadioButton6))

# Add all the Form controls on one line 
$form.Controls.AddRange(@($MyGroupBox,$OKButton,$CancelButton))

# Assign the Accept and Cancel options in the form to the corresponding buttons
$form.AcceptButton = $OKButton
$form.CancelButton = $CancelButton

# Activate the form
$form.Add_Shown({$form.Activate()})

# Get the results from the button click
$dialogResult = $form.ShowDialog()

# If the OK button is selected
if ($dialogResult -eq "OK"){
	$i = 0;
	if($RadioButton1.Checked)
	{  $i = 1 }
	elseif($RadioButton2.Checked)
	{ $i = 2 }
	elseif($RadioButton3.Checked)
	{ $i = 3 }
	elseif($RadioButton4.Checked)
	{ $i = 4 }
	elseif($RadioButton5.Checked)
	{ $i = 5 }
	elseif($RadioButton6.Checked)
	{ $i = 6 }
	
	setEnvVars($i)
}

#Read-Host -Prompt "Press Enter to exit..."
